#
# spec file for package python-coveralls-check
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without libalternatives
%{?sle15_python_module_pythons}
Name:           python-coveralls-check
Version:        1.2.1
Release:        6.1
Summary:        Coverage checking using https://coveralls.io/
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/cjw296/coverage-check
Source:         https://files.pythonhosted.org/packages/source/c/coveralls-check/coveralls-check-%{version}.tar.gz
# https://github.com/cjw296/coveralls-check/issues/3
Patch0:         python-coveralls-check-no-mock.patch
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  alts
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       alts
Requires:       python-backoff
Requires:       python-requests
Requires:       python-setuptools
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module backoff}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module responses}
BuildRequires:  %{python_module testfixtures}
# /SECTION
%python_subpackages

%description
A helper to check https://coveralls.io for a given commit hash.

%prep
%setup -q -n coveralls-check-%{version}
%autopatch -p1

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/coveralls-check
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest tests.py

%pre
# Removing old update-alternatives entries.
%python_libalternatives_reset_alternative coveralls-check

%files %{python_files}
%doc README.rst
%license LICENSE.rst
%python_alternative %{_bindir}/coveralls-check
%{python_sitelib}/coveralls[-_]check.py
%{python_sitelib}/coveralls[-_]check-%{version}*-info
%pycache_only %{python_sitelib}/__pycache__/coveralls[-_]check*

%changelog
* Wed Jun  4 2025 Felix Stegmeier <felix.stegmeier@suse.com>
- Fix usage of libalternatives
* Fri May 16 2025 Markéta Machová <mmachova@suse.com>
- Convert to pip-based build
* Thu Mar 21 2024 Max Lin <mlin@suse.com>
- Add %%{?sle15_python_module_pythons}
* Wed Mar  9 2022 pgajdos@suse.com
- do not require python-mock for build
- added patches:
  + python-coveralls-check-no-mock.patch
* Wed May 27 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Wed May 22 2019 pgajdos@suse.com
- version update to 1.2.1
  * Fix packaging and copyright.
  * Add support for Coveralls parallel build stuff.
* Sun Mar  3 2019 John Vandenberg <jayvdb@gmail.com>
- Remove eight incorrect Suggests
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Sun Jul 29 2018 jengelh@inai.de
- Use noun phrase in summary.
* Thu May 24 2018 toddrme2178@gmail.com
- spec file cleanups
- fix tests
* Tue Sep 26 2017 t.gruner@katodev.de
- Initial release version 1.1.0
